summaryrefslogtreecommitdiff
path: root/src/lib/dcp_content.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-07-23 15:10:11 +0100
committerCarl Hetherington <cth@carlh.net>2018-07-23 15:10:11 +0100
commita5c629cb9b638b67a0e4c2d26fe9ab2e124bf0eb (patch)
tree6cd463704f413259516e2888704272a371a108a6 /src/lib/dcp_content.h
parentdf17bbd25da69fc38eb2dcd8b4a2531cf0bab0bc (diff)
Tidy up after mass rename.
Diffstat (limited to 'src/lib/dcp_content.h')
-rw-r--r--src/lib/dcp_content.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/lib/dcp_content.h b/src/lib/dcp_content.h
index fedc43d64..cccf127c3 100644
--- a/src/lib/dcp_content.h
+++ b/src/lib/dcp_content.h
@@ -36,9 +36,9 @@ public:
static int const NEEDS_ASSETS;
static int const REFERENCE_VIDEO;
static int const REFERENCE_AUDIO;
- static int const REFERENCE_CAPTION;
+ static int const REFERENCE_TEXT;
static int const NAME;
- static int const CAPTIONS;
+ static int const TEXTS;
};
class ContentPart;
@@ -108,17 +108,17 @@ public:
bool can_reference_audio (std::string &) const;
- void set_reference_caption (TextType type, bool r);
+ void set_reference_text (TextType type, bool r);
- /** @param type Original type of captions in the DCP.
- * @return true if these captions are to be referenced.
+ /** @param type Original type of texts in the DCP.
+ * @return true if these texts are to be referenced.
*/
- bool reference_caption (TextType type) const {
+ bool reference_text (TextType type) const {
boost::mutex::scoped_lock lm (_mutex);
- return _reference_caption[type];
+ return _reference_text[type];
}
- bool can_reference_caption (TextType type, std::string &) const;
+ bool can_reference_text (TextType type, std::string &) const;
void set_cpl (std::string id);
@@ -166,11 +166,11 @@ private:
* rather than by rewrapping.
*/
bool _reference_audio;
/** true if the captions in this DCP should be included in the output by reference
* rather than by rewrapping. The types here are the original caption types,
* not what they are being used for.
*/
- bool _reference_caption[CAPTION_COUNT];
+ bool _reference_text[TEXT_COUNT];
boost::optional<dcp::Standard> _standard;
bool _three_d;
@@ -166,11 +166,11 @@ private:
*/
bool _reference_audio;
- /** true if the captions in this DCP should be included in the output by reference
- * rather than by rewrapping. The types here are the original caption types,
+ /** true if the texts in this DCP should be included in the output by reference
+ * rather than by rewrapping. The types here are the original text types,
* not what they are being used for.
*/